Stan Math Library: stan::math::chainable_alloc Class Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | List of all members
stan::math::chainable_alloc Class Reference

A chainable_alloc is an object which is constructed and destructed normally but the memory lifespan is managed along with the arena allocator for the gradient calculation. More...

`#include <chainable_alloc.hpp>`

Inheritance diagram for stan::math::chainable_alloc:

## Public Member Functions
| chainable_alloc ()
virtual | ~chainable_alloc ()

## Detailed Description

A chainable_alloc is an object which is constructed and destructed normally but the memory lifespan is managed along with the arena allocator for the gradient calculation.

A chainable_alloc instance must be created with a call to operator new for memory management.

Definition at line 16 of file chainable_alloc.hpp.

## Constructor & Destructor Documentation

stan::math::chainable_alloc::chainable_alloc | ( |  | ) |
| inline

Definition at line 18 of file chainable_alloc.hpp.

virtual stan::math::chainable_alloc::~chainable_alloc | ( |  | ) |
| inlinevirtual

Definition at line 21 of file chainable_alloc.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/core/chainable_alloc.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.